## 1.1.0 (2023-06-12)

### Feat

- add fix version and parents in metrics data

## 1.0.0 (2023-03-06)

### Refactor

- change the config to snake case

## 0.1.0 (2023-03-01)

### Feat

- create basic framework with only status metric

### Fix

- pylint errors related to exception and dict
